-- This filters worker runs to only include those used in any of the kinds
-- of ML results we have.  Doing it using LEFT JOIN would require 9 joins and
-- fills up the RAM.  Adding DISTINCT to all the SELECT queries of the UNION
-- slows this query down by ~20%.  Using multiple INs instead of a UNION makes
-- this query twice as slow.

-- Note that exports may fail if an ML result uses a WorkerRun that has a
-- WorkerVersion that is not the worker_version_id, as the version may not
-- have been exported properly and the FK constraint may fail.
SELECT
    run.id,
    run.version_id,
    run.model_version_id,
    model.id,
    model.name,
    run.configuration_id,
    configuration.configuration
FROM process_workerrun run
LEFT JOIN process_workerconfiguration configuration ON configuration.id = run.configuration_id
LEFT JOIN training_modelversion modelversion ON modelversion.id = run.model_version_id
LEFT JOIN training_model model ON model.id = modelversion.model_id
WHERE run.id IN (
    SELECT worker_run_id FROM documents_element WHERE corpus_id = '{corpus_id}'::uuid
UNION ALL
    SELECT worker_run_id FROM documents_entity WHERE corpus_id = '{corpus_id}'::uuid
UNION ALL
    SELECT classification.worker_run_id
    FROM documents_classification classification
    INNER JOIN documents_element element ON (element.id = classification.element_id)
    WHERE element.corpus_id = '{corpus_id}'::uuid
UNION ALL
    SELECT transcription.worker_run_id
    FROM documents_transcription transcription
    INNER JOIN documents_element element ON (element.id = transcription.element_id)
    WHERE element.corpus_id = '{corpus_id}'::uuid
UNION ALL
    SELECT te.worker_run_id
    FROM documents_transcriptionentity te
    INNER JOIN documents_entity entity ON (te.entity_id = entity.id)
    WHERE entity.corpus_id = '{corpus_id}'::uuid
UNION ALL
    SELECT md.worker_run_id
    FROM documents_metadata md
    INNER JOIN documents_element element ON (md.element_id = element.id)
    WHERE element.corpus_id = '{corpus_id}'::uuid
)
