from django.db.models import Manager

from arkindex.users.managers import BaseACLManager
from arkindex.users.models import Role


class TaskManager(Manager):
    def parents(self, task):
        """
        List all tasks that a task depends on, directly or not.
        A PostgreSQL recursive query is used for better performances.
        """
        return self.raw(
            """
            with recursive parents(id) as (
                select to_task_id
                    from ponos_task_parents j
                    where j.from_task_id = %s
                union all
                    select j.to_task_id
                    from ponos_task_parents as j, parents
                    where j.from_task_id = parents.id
            )
            select distinct * from parents
            """,
            [task.id],
        )


class FarmManager(BaseACLManager):

    def available(self, user):
        """
        Farms that are visible to the user, and where process can run.
        """
        # Without authentication, or as a Ponos agent, nothing is available.
        # Agents are not users, filtering on them will make Django raise exceptions, so we have to handle them separately.
        if user.is_anonymous or getattr(user, 'is_agent', False):
            return self.none()

        # All farms are available to instance admins
        if user.is_admin:
            return self.all()

        # Regular users need guest access to each farm
        return self.filter(id__in=self.filter_rights(user, self.model, Role.Guest.value).values('id'))
