# Generated by Django 4.1.7 on 2023-06-27 13:21

from django.core.validators import RegexValidator
from django.db import migrations, models

from arkindex.ponos.models import generate_seed, task_token_default


class Migration(migrations.Migration):

    dependencies = [
        ('ponos', '0003_remove_workflow'),
    ]

    operations = [
        # Remove the implicit LIKE index on Farm.seed and make the unique constraint explicit
        # We do the dropping and renaming ourselves, instead of letting Django unnecessarily drop and re-create the constraint.
        migrations.RunSQL(
            [
                "DROP INDEX ponos_farm_seed_c470c8df_like;",
                "ALTER TABLE ponos_farm RENAME CONSTRAINT ponos_farm_seed_key TO unique_farm_seed;",
            ],
            reverse_sql=[
                "ALTER TABLE ponos_farm RENAME CONSTRAINT unique_farm_seed TO ponos_farm_seed_key;",
                "CREATE INDEX ponos_farm_seed_c470c8df_like ON ponos_farm (seed varchar_pattern_ops);",
            ],
            state_operations=[
                migrations.AlterField(
                    model_name='farm',
                    name='seed',
                    field=models.CharField(
                        default=generate_seed,
                        max_length=64,
                        validators=[RegexValidator('^[0-9a-f]{64}$')],
                    ),
                ),
                migrations.AddConstraint(
                    model_name='farm',
                    constraint=models.UniqueConstraint(
                        models.F('seed'),
                        name='unique_farm_seed',
                    ),
                ),
            ],
            # This can be removed by manage.py squashmigrations
            elidable=True,
        ),
        # Remove the implicit LIKE index on Secret.name and make the unique constraint explicit
        # We do the dropping and renaming ourselves, instead of letting Django unnecessarily drop and re-create the constraint.
        migrations.RunSQL(
            [
                "DROP INDEX ponos_secret_name_d5cfc035_like;",
                "ALTER TABLE ponos_secret RENAME CONSTRAINT ponos_secret_name_key TO unique_secret_names;",
            ],
            reverse_sql=[
                "ALTER TABLE ponos_secret RENAME CONSTRAINT unique_secret_names TO ponos_secret_name_key;",
                "CREATE INDEX ponos_secret_name_d5cfc035_like ON ponos_secret (name varchar_pattern_ops);",
            ],
            state_operations=[
                migrations.AlterField(
                    model_name='secret',
                    name='name',
                    field=models.CharField(max_length=250),
                ),
                migrations.AddConstraint(
                    model_name='secret',
                    constraint=models.UniqueConstraint(
                        models.F('name'),
                        name='unique_secret_names',
                    ),
                ),
            ],
            # This can be removed by manage.py squashmigrations
            elidable=True,
        ),
        # Remove the implicit LIKE index on Task.token and make the unique constraint explicit
        # We do the dropping and renaming ourselves, instead of letting Django unnecessarily drop and re-create the constraint.
        migrations.RunSQL(
            [
                "DROP INDEX ponos_task_token_8d8e6d89_like;",
                "ALTER TABLE ponos_task RENAME CONSTRAINT ponos_task_token_key TO unique_task_token;",
            ],
            reverse_sql=[
                "ALTER TABLE ponos_task RENAME CONSTRAINT unique_task_token TO ponos_task_token_key;",
                "CREATE INDEX ponos_task_token_8d8e6d89_like ON ponos_task (token varchar_pattern_ops);",
            ],
            state_operations=[
                migrations.AlterField(
                    model_name='task',
                    name='token',
                    field=models.CharField(
                        default=task_token_default,
                        max_length=52,
                    ),
                ),
                migrations.AddConstraint(
                    model_name='task',
                    constraint=models.UniqueConstraint(
                        models.F('token'),
                        name='unique_task_token',
                    ),
                ),
            ],
            # This can be removed by manage.py squashmigrations
            elidable=True,
        ),
    ]
