from django.contrib.auth.models import BaseUserManager
from django.db.models import Manager


class UserManager(BaseUserManager):
    def create_user(self, email, password=None, display_name=None):
        """
        Creates and saves a User with the given email and password.
        """
        if not email:
            raise ValueError('Users must have an email address')

        if not display_name:
            # Try to automatically define a display name
            try:
                display_name = email.split('@')[0].replace('.', ' ').title()
            except Exception:
                display_name = email

        user = self.model(
            display_name=display_name,
            email=self.normalize_email(email),
        )

        user.set_password(password)
        user.save(using=self._db)
        return user

    def create_superuser(self, email, password, display_name=None):
        """
        Creates and saves a superuser with the given email and password.
        """
        user = self.create_user(
            email,
            display_name=display_name,
            password=password,
        )
        user.is_admin = True
        user.save(using=self._db)
        return user


class BaseACLManager(Manager):

    def filter_rights(self, *args, **kwargs):
        # Avoid circular dependencies:
        # models with ACL set up are imported in arkindex.users.utils to be added to an enum,
        # and models with ACL will also be using managers that inherit from this manager,
        # with most ACL checks depending on arkindex.users.utils.filter_rights.
        from arkindex.users.utils import filter_rights
        return filter_rights(*args, **kwargs)
